# Generated by Django 2.2.5 on 2024-06-15 02:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blogs', '0004_auto_20240615_1044'),
    ]

    operations = [
        migrations.AddField(
            model_name='blog',
            name='release_date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='blog',
            name='thumbnail',
            field=models.ImageField(blank=True, null=True, upload_to='thumbnail', verbose_name='サムネイル（空欄可）'),
        ),
    ]
