
<div class="markdownx row">
    <div class="col-md-6 col-lg-6">
        {% include 'django/forms/widgets/textarea.html' %}
    </div>
    <div class="col-md-6 col-lg-6">
	<div class="markdownx-preview"></div>
    </div>
</div>
