/*-- index.html private_index.html --*/

/* 大見出し */
figure {
  padding-top: 5%;
  padding-bottom: 5%;
  padding-left: 3%;
  padding-right: 3%;
  margin-bottom: 3%;
}

/* リストカード */
/* カードがホバーされた時に浮き上がったように表示させる設定 --*/
.card {
    position:relative;
    top: 0;
    transition: all 0.5s;
}
.card:hover {
    top: -5px;
    box-shadow: 0 8px 13px rgba(0, 0, 0, 0.4);
}

/* ページネーション */
.pagination {
  margin: 0 auto;
  margin-top: 3%;
  margin-bottom: 3%;
}

/* -- include_index.html終 --*/
