# Generated by Django 2.2.5 on 2024-07-03 00:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blogs', '0006_auto_20240618_1317'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='color',
            field=models.CharField(choices=[['gray', 'gray'], ['crimson', 'crimson'], ['royalblue', 'royalblue'], ['darkgreen', 'darkgreen'], ['darkolivegreen', 'darkolivegreen'], ['darkorange', 'darkorange'], ['darkviolet', 'darkviolet']], default='gray', max_length=50),
        ),
    ]
