/*-- detail.html --*/

/* マークダウンスタイル */
.blogs-markdown-style p { /* pタグの行間を空ける */
  line-height: 200%;
  margin-left: 3%;
  margin-right: 3%;
}

/* 目次（TOC）*/
.blogs-markdown-style .toc .toctitle {
  font-size: 20px; /* 目次の文字サイズ */
  padding-left: 40%; /* 左側から５０％空けて真ん中にする */

}

.blogs-markdown-style .toc {
  background-color: whitesmoke; /* 目次のバックカラーを変える */
  border-radius: 10px;
}

.blogs-markdown-style .toc a{ /* テキスト内の目次リンクのデザイン */
  text-decoration:none;
}

/* ulタグからolに変更 */
.blogs-markdown-style .toc ul {
  counter-reset: count 0;
  list-style-type: none;
}

/* tocリストに番号付けする */
.blogs-markdown-style .toc ul li:before {
  counter-increment: count 1;
  content: counters(count, "-") ". ";
  font-size: 20px;
}

.blogs-markdown-style .toc ul li {
  padding: 1%; /* 目次の各項目に余白を空ける */
}

.blogs-markdown-style .toc a {
  color: gray;
}

/* h2（##）ヘッダー */
.blogs-markdown-style h2 {
  padding: 0.5em;
  color: gray;
  background: whitesmoke;
  /* border-left: solid 5px violet; */
  margin-top: 10%;
  margin-bottom: 3%;
}

/* h3（###）タグ */
.blogs-markdown-style h3 {
  padding: 0.5em;
  color: gray;
  /* border-left: solid 5px violet; */
  margin-top: 10%;
  margin-bottom: 3%;
}

.blogs-markdown-style .headerlink { /* 各ヘッダーのパーマリンクデザイン */
  text-decoration:none;
  color: gray;
}

/* テーブル */
.blogs-markdown-style table {
  width: 80%;
  margin-top: 4%;
  margin-bottom: 4%;
  margin-left: 2%;
}

/* 画像 */
.blogs-markdown-style img {
  width: 100%;
  height: auto;
  margin-top: 5%;
  margin-bottom: 5%;
  box-shadow: 0 1px 8px #777;
  border-radius: 10px; /* 角を丸める */
}

/* インラインコードのハイライト */
.blogs-markdown-style p code {
  margin-left: 0.5%;
  margin-right: 0.5%;
  padding-top: 0%;
  padding-bottom: 0.3%;
  padding-left: 0.5%;
  padding-right: 0.5%;
  background-color: #333; /* コードハイライトと統一 */
  color: white;
  border-radius: 3px; /* 角を丸める */
}

/* コードハイライト */
.blogs-markdown-style pre {
  margin-top: 5%;
  margin-bottom: 5%;
}

.blogs-markdown-style pre code{
  padding-top: 3%;
  padding-bottom: 3%;
  padding-left: 3%;
  padding-right: 3%;
}
/* admonitionの忠告 */

/* 忠告本体のデザイン */
.blogs-markdown-style .admonition {
  margin-top: 3%;
  margin-bottom: 3%;
  margin-left: 3%;
  margin-right: 3%;
  padding: 3%;
  border-radius: 0px; /* 角を丸める */
}

.blogs-markdown-style .admonition-title { /* 忠告表示のタイトルのデザイン */
  font-weight: bold;
  font-size: 150%;
}

/* 忠告表示内の画像サイズ */
.blogs-markdown-style .admonition img {
  width: 90%;
  height: 8%;
}

.blogs-markdown-style .overview { /* 概要のデザイン */
  border-left: solid 5px gray;
  background: whitesmoke;
}

.blogs-markdown-style .attention { /* 注意のデザイン */
  border-left: solid 5px hotpink;
  background-color: lightpink;
}

.blogs-markdown-style .supplement { /* 補足のデザイン */
  border-left: solid 5px yellow;
  background-color: lightyellow;
}
/* admonitionの忠告終 */

/*-- detail.html --*/
