<nav class="navbar sticky-top navbar-expand-lg bg-body-tertiary">
  <div class="container-fluid">
    <a class="navbar-brand" href="{% url 'blogs:index' %}">
      <i class="bi bi-book"></i> Blogトップ
    </a>
    <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
      <span class="navbar-toggler-icon"></span>
    </button>
    <div class="collapse navbar-collapse justify-content-center" id="navbarSupportedContent">
      <ul class="navbar-nav justify-content-center">
	<!-- カテゴリー -->
	{% for category in category_list %}
        <li class="nav-item">
	  <a class="nav-link active" aria-current="page" href="{% url 'blogs:category' category %}">{{ category }}</a>
        </li>
	{% endfor %}
	<!-- カテゴリー終 -->
	<!-- 管理人だけ表示 -->
	{% if request.user.is_superuser %}
	<li class="nav-item">
	  <a class="nav-link active" aria-current="page" href="{% url 'blogs:private_index' %}">非表示</a>
	</li>
	<li class="nav-item dropdown">
	  <a title="作成" class="nav-link" href="#" role="button" data-bs-toggle="dropdown" aria-expanded="false">
	    <i class="bi bi-gear" style="font-size:150%;"></i>
	  </a>
	  <ul class="dropdown-menu">
	    <li><a class="dropdown-item" href="{% url 'blogs:new_blog' %}">新規作成</a></li>
	  </ul>
	</li>
	{% endif %}
      </ul>
    </div>
  </div>
</nav>
